==> prestashop_1.4.8.2.zip: prestashop/modules/avalaratax/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{avalaratax}prestashop>avalaratax_fea2a64a31f1513f4b2565ebfaff597b'] = 'Avalara - AvaTax';
$_MODULE['<{avalaratax}prestashop>avalaratax_ae8a727f868a8bbca075451c34154bfe'] = 'Les taxes de vente sont compliquées. Avatax facilite les taxes.';
$_MODULE['<{avalaratax}prestashop>avalaratax_6e25586fe78488784e764b8c7e523099'] = 'Le module a été installé avec succès mais le(s) fichier(s) suivant(s) existe(nt) déjà. Veuillez fusionner le(s) fichier(s) manuellement.';
$_MODULE['<{avalaratax}prestashop>avalaratax_53c2b2432a6d2b3e69298041223f2677'] = 'Les produits que vous avez choisis ont été annulés.';
$_MODULE['<{avalaratax}prestashop>avalaratax_580bc7347384fe1e3e2fdaf3930fdb00'] = 'Les règles de taxes pour les USA ont été réécrites par le module Avalara Tax';
$_MODULE['<{avalaratax}prestashop>avalaratax_2929b1675a0788e25b46dd923bf8d6f4'] = 'Tax Code (Avalara)';
$_MODULE['<{avalaratax}prestashop>avalaratax_56bb4e1f91985e7319c1d5cbe47096fe'] = 'L\'adresse que vous avez soumise a été validé.';
$_MODULE['<{avalaratax}prestashop>avalaratax_45d416b0d62f0e9579a08fac59a8fe48'] = 'L\'erreur suivante a été générée pendant la validation de l\'adresse';
$_MODULE['<{avalaratax}prestashop>avalaratax_ffea2d321be109fc7243cfeb515fe257'] = 'Choississez votre état (si applicable)';
$_MODULE['<{avalaratax}prestashop>avalaratax_63406c9482c644975f227cc93788e8fb'] = 'Choississez votre pays';
$_MODULE['<{avalaratax}prestashop>avalaratax_76b5416ce9c34cc4d45e337db00a653a'] = 'Ce module est prévu pour fonctionner SEULEMENT pour les États-Unis d\'Amérique et le Canada';
$_MODULE['<{avalaratax}prestashop>avalaratax_0173b19e723017c74ca1d34bc7e6515b'] = 'Comment configurer le module Avalara Tax :';
$_MODULE['<{avalaratax}prestashop>avalaratax_3a0b9a760cae0b64183e2ed2b8b5789b'] = 'Remplir les champs numéro de compte, clé de licence et code de la société avec les données fournies par Avalara.';
$_MODULE['<{avalaratax}prestashop>avalaratax_aea420a9b05a0b1c5c1823e13cdf5c4b'] = 'Spécifiez l\'adresse d\'origine. Ceci est le point de départ de vos colis (cela doit être une';
$_MODULE['<{avalaratax}prestashop>avalaratax_eb60dad6b9af2493998d6201caae1faa'] = 'Adresse aux Etats Unis valide';
$_MODULE['<{avalaratax}prestashop>avalaratax_558e731e858fbdb4de1b01be9283e7c0'] = 'Objectif du module :';
$_MODULE['<{avalaratax}prestashop>avalaratax_a035358b6b8c497a70d2c5a838c27e6a'] = 'Ce service est le plus rapide, facile, précis et abordable pour calculer les ventes et les taxes; gérer les certificats d\'exemption; renvoi de fichiers; et les remises de paiements en Amérique du Nord et au-delà.';
$_MODULE['<{avalaratax}prestashop>avalaratax_343618e9fcce53224cc7a47c2145c5e5'] = 'Quelles sont les modifications que le module fait sur ma boutique ?';
$_MODULE['<{avalaratax}prestashop>avalaratax_227c1f6f0609c433fc3530aced1dd1a9'] = 'Tax.php, AddressController.php, and AuthController.php seront overridés.';
$_MODULE['<{avalaratax}prestashop>avalaratax_ed844b12d383390f1e8ac7796312390d'] = '[Onglet Paiement -> Taxes] et [Onglet Paiement -> Règles de taxes] les configurations seront overridés pour les US.';
$_MODULE['<{avalaratax}prestashop>avalaratax_3a2eb2cc29ccc9fc619e47fe4df5b148'] = 'Sur les détails du produit (produit en mode édition) un champ \"Code général de taxe\" sera ajouté vous permettant de spécifier un code fiscal valable pour chacun de vos produits.\"';
$_MODULE['<{avalaratax}prestashop>avalaratax_254f642527b45bc260048e30704edb39'] = 'Configuration';
$_MODULE['<{avalaratax}prestashop>avalaratax_6910f753ce21ab6b256a2440296185df'] = 'Références AvaTax';
$_MODULE['<{avalaratax}prestashop>avalaratax_2fcecaf04456ae2ceac826fd0ccaaf1c'] = 'Numéro de compte';
$_MODULE['<{avalaratax}prestashop>avalaratax_5d5c4ad5db4bd841e161e43ac45bc5c6'] = 'Clé de licence';
$_MODULE['<{avalaratax}prestashop>avalaratax_e6b391a8d2c4d45902a23a8b6585703d'] = 'URL';
$_MODULE['<{avalaratax}prestashop>avalaratax_5f8257b5273b995afe894c6b851f115c'] = 'Code de la société';
$_MODULE['<{avalaratax}prestashop>avalaratax_c6a0ae4c3ae26cc37b15d7cf6494547c'] = 'Situé dans le coin en haut à droite de votre console d\'administration AvaTax';
$_MODULE['<{avalaratax}prestashop>avalaratax_9daf1fb753b42c3cdc8f1d01669cd6d8'] = 'Sauvegarder la configuration';
$_MODULE['<{avalaratax}prestashop>avalaratax_79ddd6cfbf01f63986f7b114ecc2ca95'] = 'Cliquez ici pour tester la connection';
$_MODULE['<{avalaratax}prestashop>avalaratax_dae8ace18bdcbcc6ae5aece263e14fe8'] = 'Options';
$_MODULE['<{avalaratax}prestashop>avalaratax_075f49c9bb1da54fd022ddcfb6a9f09b'] = 'Activer la validation d\'adresse';
$_MODULE['<{avalaratax}prestashop>avalaratax_355fc749cbbfcba999612f3a91cd2667'] = 'Activer le calcul des taxes';
$_MODULE['<{avalaratax}prestashop>avalaratax_4b8dfce98a161ad3ad9a5eab52225d86'] = 'Activer la normalisation des adresses en majuscule';
$_MODULE['<{avalaratax}prestashop>avalaratax_db669c6377ab90eef78800a48fd4a453'] = 'Temps de requête dépassé';
$_MODULE['<{avalaratax}prestashop>avalaratax_783e8e29e6a8c3e22baa58a19420eb4f'] = 'secondes';
$_MODULE['<{avalaratax}prestashop>avalaratax_5b092e4c3fc280f8d23bc52c544498d8'] = 'Rafraichir le cache des taxes tous les jours :';
$_MODULE['<{avalaratax}prestashop>avalaratax_640fd0cc0ffa0316ae087652871f4486'] = 'minutes';
$_MODULE['<{avalaratax}prestashop>avalaratax_06f4f7bd90b1c8a0145d18ee55c265c4'] = 'Effacer le cache';
$_MODULE['<{avalaratax}prestashop>avalaratax_bf58340449ab95a854343bfb704b9638'] = 'Default Post/Commit/Cancel/Refund Options';
$_MODULE['<{avalaratax}prestashop>avalaratax_7a9409d7e2a131729d052c4f0c40172c'] = 'Quand le statut d\'une commande est mis à jour, les options suivantes seront utilisées pour mettre à jour les données d\'Avalara.';
$_MODULE['<{avalaratax}prestashop>avalaratax_004bf6c9a40003140292e97330236c53'] = 'Action';
$_MODULE['<{avalaratax}prestashop>avalaratax_4bb3e6ea4b1aa93c3429e410129b4be4'] = 'Statuts de commande dans votre boutique';
$_MODULE['<{avalaratax}prestashop>avalaratax_c2557908b54658949a9cf6363befb940'] = 'Envoyer une commande à Avalara';
$_MODULE['<{avalaratax}prestashop>avalaratax_6bcf0964b8e694d02aba7d7dfcdf5442'] = '[ERREUR] Aucune valeur par défaut n\'a été trouvée. Veuillez restaurer les statuts par défaut de PrestaShop';
$_MODULE['<{avalaratax}prestashop>avalaratax_73d84adcfc3b54cf9bec85791236b73d'] = 'Commit order to Avalara';
$_MODULE['<{avalaratax}prestashop>avalaratax_0316320415f5e35b004c81ae93cc36bd'] = 'Delete order from Avalara';
$_MODULE['<{avalaratax}prestashop>avalaratax_1fc4faeb7e0ececc2a6bd54abda65f73'] = 'Void order in Avalara';
$_MODULE['<{avalaratax}prestashop>avalaratax_c7a504ef03bdf275db8151959034f00b'] = 'Adresse d\'origine par défaut';
$_MODULE['<{avalaratax}prestashop>avalaratax_add3df7ab84caab59b62f89fdd35ac1f'] = 'Adresse ligne 1';
$_MODULE['<{avalaratax}prestashop>avalaratax_6a7b0d5f2f1354e398923d81b0e4d6ab'] = 'Adresse ligne 2';
$_MODULE['<{avalaratax}prestashop>avalaratax_57d056ed0984166336b7879c2af3657f'] = 'Ville';
$_MODULE['<{avalaratax}prestashop>avalaratax_46a2a41cc6e552044816a2d04634545d'] = 'Etat';
$_MODULE['<{avalaratax}prestashop>avalaratax_5e178542b85fb18ca3c459e9a95f4f2e'] = 'Code postal';
$_MODULE['<{avalaratax}prestashop>avalaratax_59716c97497eb9694541f7c3d37b1a4d'] = 'Pays';
$_MODULE['<{avalaratax}prestashop>avalaratax_9410e0f9048d0fdecef38e745ce2e9ed'] = 'Console d\'administration AvaTax';
$_MODULE['<{avalaratax}prestashop>avalaratax_f47aa2664e16e45a8b17e2f0a8a05b1c'] = 'Identifiez vous sur la console d\'administration AvaTax';
$_MODULE['<{avalaratax}prestashop>avalaratax_c888438d14855d7d96a2724ee9c306bd'] = 'Configurations mises à jour';
$_MODULE['<{avalaratax}prestashop>avalaratax_70b07b7f1a6e3c7f20fd75461aaefb9f'] = 'Test de connection effectuée avec succès';
$_MODULE['<{avalaratax}prestashop>avalaratax_f63f3c0a7a1fa62fa64ba8e8763f1106'] = 'La version de Ping est :';
$_MODULE['<{avalaratax}prestashop>avalaratax_224f5e74c7e0d63742fcff8e1776b3f0'] = 'La date d\'expiration de la licence est :';
$_MODULE['<{avalaratax}prestashop>avalaratax_63a77eaf9f310dc5def6709c2887dcc4'] = 'Le test de connection a échoué';
$_MODULE['<{avalaratax}prestashop>avalaratax_6053c937d7fec8bd03e6a9dce45b4104'] = 'Le compte ou la clé de licence est incorrect. Veuillez vérifier le compte et la clé de licence avant de tester la connexion à nouveau.';
$_MODULE['<{avalaratax}prestashop>avalaratax_3b4f001aa4a4715a2449b8affb2eb3f5'] = 'Erreur(s) :';
$_MODULE['<{avalaratax}prestashop>avalaratax_d284d38f7ef7a9d00d82f8395510c845'] = 'Les commandes que vous avez choisies ont été postées.';
$_MODULE['<{avalaratax}prestashop>avalaratax_91b736ea6bbca1d447985ff6262cde25'] = 'L\'erreur suivante a été générée pendant l\'envoi des commandes choisies à Avalara.';
$_MODULE['<{avalaratax}prestashop>avalaratax_62b4a111d5272f0d5e6da820de9fee8d'] = 'Les commandes que vous avez choisies ont été commités.';
$_MODULE['<{avalaratax}prestashop>avalaratax_c45e7677f4f5ccc23c0e4a6989308e8e'] = 'L\'erreur suivante a été générée pendant l\'annulation des commandes choisies d\'Avalara.';
$_MODULE['<{avalaratax}prestashop>avalaratax_2ac3d2e77dddb4c35713ba077a3a9639'] = 'Les commandes que vous avez choisies ont été annulées.';

==> prestashop_1.4.9.0.zip: prestashop/modules/avalaratax/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{avalaratax}prestashop>avalaratax_fea2a64a31f1513f4b2565ebfaff597b'] = 'Avalara - AvaTax';
$_MODULE['<{avalaratax}prestashop>avalaratax_ae8a727f868a8bbca075451c34154bfe'] = 'Les taxes de vente sont compliquées. Avatax facilite les taxes.';
$_MODULE['<{avalaratax}prestashop>avalaratax_abec8ce9e661c64f0731e0bf94473d89'] = 'Erreur lors de la suppression de l\'override';
$_MODULE['<{avalaratax}prestashop>avalaratax_4ce97a64a65a5ef27f9d497481f6d1bf'] = 'Ce fichier override existe deja, veulliez le fusionner manuellement';
$_MODULE['<{avalaratax}prestashop>avalaratax_954eea3c07ec89bdb2bd2b59c016e7ed'] = 'Erreur lors de la copie de l\'override :';
$_MODULE['<{avalaratax}prestashop>avalaratax_53c2b2432a6d2b3e69298041223f2677'] = 'Les produits que vous avez choisis ont été annulés.';
$_MODULE['<{avalaratax}prestashop>avalaratax_2929b1675a0788e25b46dd923bf8d6f4'] = 'Code taxe (Avalara)';
$_MODULE['<{avalaratax}prestashop>avalaratax_6c18511d259e56b91071c673ee486fd1'] = 'Code taxe:';
$_MODULE['<{avalaratax}prestashop>avalaratax_802f657935b88d6d5047aa87b3e20efd'] = 'Les regeles de taxes sont surchargés par le module Avalara';
$_MODULE['<{avalaratax}prestashop>avalaratax_6a8c8129f7d86941bd699a1e898ce102'] = 'Erreur lors du calcul des taxes';
$_MODULE['<{avalaratax}prestashop>avalaratax_56bb4e1f91985e7319c1d5cbe47096fe'] = 'L\'adresse que vous avez soumise a été validé.';
$_MODULE['<{avalaratax}prestashop>avalaratax_5e75f748e7f06f54b073c307c8062c25'] = 'Les erreurs suivantes sont survenues lors de la validation de l\'adresse :';
$_MODULE['<{avalaratax}prestashop>avalaratax_ffea2d321be109fc7243cfeb515fe257'] = 'Choississez votre état (si applicable)';
$_MODULE['<{avalaratax}prestashop>avalaratax_63406c9482c644975f227cc93788e8fb'] = 'Choississez votre pays';
$_MODULE['<{avalaratax}prestashop>avalaratax_76b5416ce9c34cc4d45e337db00a653a'] = 'Ce module est prévu pour fonctionner SEULEMENT pour les États-Unis d\'Amérique et le Canada';
$_MODULE['<{avalaratax}prestashop>avalaratax_0173b19e723017c74ca1d34bc7e6515b'] = 'Comment configurer le module Avalara Tax :';
$_MODULE['<{avalaratax}prestashop>avalaratax_3a0b9a760cae0b64183e2ed2b8b5789b'] = 'Remplir les champs numéro de compte, clé de licence et code de la société avec les données fournies par Avalara.';
$_MODULE['<{avalaratax}prestashop>avalaratax_aea420a9b05a0b1c5c1823e13cdf5c4b'] = 'Spécifiez l\'adresse d\'origine. Ceci est le point de départ de vos colis (cela doit être une';
$_MODULE['<{avalaratax}prestashop>avalaratax_eb60dad6b9af2493998d6201caae1faa'] = 'Adresse aux Etats Unis valide';
$_MODULE['<{avalaratax}prestashop>avalaratax_558e731e858fbdb4de1b01be9283e7c0'] = 'Objectif du module :';
$_MODULE['<{avalaratax}prestashop>avalaratax_a035358b6b8c497a70d2c5a838c27e6a'] = 'Ce service est le plus rapide, facile, précis et abordable pour calculer les ventes et les taxes; gérer les certificats d\'exemption; renvoi de fichiers; et les remises de paiements en Amérique du Nord et au-delà.';
$_MODULE['<{avalaratax}prestashop>avalaratax_343618e9fcce53224cc7a47c2145c5e5'] = 'Quelles sont les modifications que le module fait sur ma boutique ?';
$_MODULE['<{avalaratax}prestashop>avalaratax_227c1f6f0609c433fc3530aced1dd1a9'] = 'Tax.php, AddressController.php, and AuthController.php seront overridés.';
$_MODULE['<{avalaratax}prestashop>avalaratax_ed844b12d383390f1e8ac7796312390d'] = '[Onglet Paiement -> Taxes] et [Onglet Paiement -> Règles de taxes] les configurations seront overridés pour les US.';
$_MODULE['<{avalaratax}prestashop>avalaratax_3a2eb2cc29ccc9fc619e47fe4df5b148'] = 'Sur les détails du produit (produit en mode édition) un champ \"Code général de taxe\" sera ajouté vous permettant de spécifier un code fiscal valable pour chacun de vos produits.\"';
$_MODULE['<{avalaratax}prestashop>avalaratax_254f642527b45bc260048e30704edb39'] = 'Configuration';
$_MODULE['<{avalaratax}prestashop>avalaratax_6910f753ce21ab6b256a2440296185df'] = 'Références AvaTax';
$_MODULE['<{avalaratax}prestashop>avalaratax_2fcecaf04456ae2ceac826fd0ccaaf1c'] = 'Numéro de compte';
$_MODULE['<{avalaratax}prestashop>avalaratax_5d5c4ad5db4bd841e161e43ac45bc5c6'] = 'Clé de licence';
$_MODULE['<{avalaratax}prestashop>avalaratax_e6b391a8d2c4d45902a23a8b6585703d'] = 'URL';
$_MODULE['<{avalaratax}prestashop>avalaratax_5f8257b5273b995afe894c6b851f115c'] = 'Code de la société';
$_MODULE['<{avalaratax}prestashop>avalaratax_c6a0ae4c3ae26cc37b15d7cf6494547c'] = 'Situé dans le coin en haut à droite de votre console d\'administration AvaTax';
$_MODULE['<{avalaratax}prestashop>avalaratax_9daf1fb753b42c3cdc8f1d01669cd6d8'] = 'Sauvegarder la configuration';
$_MODULE['<{avalaratax}prestashop>avalaratax_79ddd6cfbf01f63986f7b114ecc2ca95'] = 'Cliquez ici pour tester la connection';
$_MODULE['<{avalaratax}prestashop>avalaratax_dae8ace18bdcbcc6ae5aece263e14fe8'] = 'Options';
$_MODULE['<{avalaratax}prestashop>avalaratax_075f49c9bb1da54fd022ddcfb6a9f09b'] = 'Activer la validation d\'adresse';
$_MODULE['<{avalaratax}prestashop>avalaratax_355fc749cbbfcba999612f3a91cd2667'] = 'Activer le calcul des taxes';
$_MODULE['<{avalaratax}prestashop>avalaratax_4b8dfce98a161ad3ad9a5eab52225d86'] = 'Activer la normalisation des adresses en majuscule';
$_MODULE['<{avalaratax}prestashop>avalaratax_9d0c2658dfe76ba5daa9f2c9af16cbf8'] = 'Activer le calcul des taxes en dehors de l\'etat';
$_MODULE['<{avalaratax}prestashop>avalaratax_db669c6377ab90eef78800a48fd4a453'] = 'Temps de requête dépassé';
$_MODULE['<{avalaratax}prestashop>avalaratax_783e8e29e6a8c3e22baa58a19420eb4f'] = 'secondes';
$_MODULE['<{avalaratax}prestashop>avalaratax_5b092e4c3fc280f8d23bc52c544498d8'] = 'Rafraichir le cache des taxes tous les jours :';
$_MODULE['<{avalaratax}prestashop>avalaratax_640fd0cc0ffa0316ae087652871f4486'] = 'minutes';
$_MODULE['<{avalaratax}prestashop>avalaratax_06f4f7bd90b1c8a0145d18ee55c265c4'] = 'Effacer le cache';
$_MODULE['<{avalaratax}prestashop>avalaratax_bf58340449ab95a854343bfb704b9638'] = 'Default Post/Commit/Cancel/Refund Options';
$_MODULE['<{avalaratax}prestashop>avalaratax_7a9409d7e2a131729d052c4f0c40172c'] = 'Quand le statut d\'une commande est mis à jour, les options suivantes seront utilisées pour mettre à jour les données d\'Avalara.';
$_MODULE['<{avalaratax}prestashop>avalaratax_004bf6c9a40003140292e97330236c53'] = 'Action';
$_MODULE['<{avalaratax}prestashop>avalaratax_4bb3e6ea4b1aa93c3429e410129b4be4'] = 'Statuts de commande dans votre boutique';
$_MODULE['<{avalaratax}prestashop>avalaratax_c2557908b54658949a9cf6363befb940'] = 'Envoyer une commande à Avalara';
$_MODULE['<{avalaratax}prestashop>avalaratax_6bcf0964b8e694d02aba7d7dfcdf5442'] = '[ERREUR] Aucune valeur par défaut n\'a été trouvée. Veuillez restaurer les statuts par défaut de PrestaShop';
$_MODULE['<{avalaratax}prestashop>avalaratax_73d84adcfc3b54cf9bec85791236b73d'] = 'Commit order to Avalara';
$_MODULE['<{avalaratax}prestashop>avalaratax_0316320415f5e35b004c81ae93cc36bd'] = 'Delete order from Avalara';
$_MODULE['<{avalaratax}prestashop>avalaratax_1fc4faeb7e0ececc2a6bd54abda65f73'] = 'Void order in Avalara';
$_MODULE['<{avalaratax}prestashop>avalaratax_c7a504ef03bdf275db8151959034f00b'] = 'Adresse d\'origine par défaut';
$_MODULE['<{avalaratax}prestashop>avalaratax_add3df7ab84caab59b62f89fdd35ac1f'] = 'Adresse ligne 1';
$_MODULE['<{avalaratax}prestashop>avalaratax_6a7b0d5f2f1354e398923d81b0e4d6ab'] = 'Adresse ligne 2';
$_MODULE['<{avalaratax}prestashop>avalaratax_57d056ed0984166336b7879c2af3657f'] = 'Ville';
$_MODULE['<{avalaratax}prestashop>avalaratax_46a2a41cc6e552044816a2d04634545d'] = 'Etat';
$_MODULE['<{avalaratax}prestashop>avalaratax_5e178542b85fb18ca3c459e9a95f4f2e'] = 'Code postal';
$_MODULE['<{avalaratax}prestashop>avalaratax_59716c97497eb9694541f7c3d37b1a4d'] = 'Pays';
$_MODULE['<{avalaratax}prestashop>avalaratax_9410e0f9048d0fdecef38e745ce2e9ed'] = 'Console d\'administration AvaTax';
$_MODULE['<{avalaratax}prestashop>avalaratax_f47aa2664e16e45a8b17e2f0a8a05b1c'] = 'Identifiez vous sur la console d\'administration AvaTax';
$_MODULE['<{avalaratax}prestashop>avalaratax_c888438d14855d7d96a2724ee9c306bd'] = 'Configurations mises à jour';
$_MODULE['<{avalaratax}prestashop>avalaratax_70b07b7f1a6e3c7f20fd75461aaefb9f'] = 'Test de connection effectuée avec succès';
$_MODULE['<{avalaratax}prestashop>avalaratax_f63f3c0a7a1fa62fa64ba8e8763f1106'] = 'La version de Ping est :';
$_MODULE['<{avalaratax}prestashop>avalaratax_224f5e74c7e0d63742fcff8e1776b3f0'] = 'La date d\'expiration de la licence est :';
$_MODULE['<{avalaratax}prestashop>avalaratax_63a77eaf9f310dc5def6709c2887dcc4'] = 'Le test de connection a échoué';
$_MODULE['<{avalaratax}prestashop>avalaratax_6053c937d7fec8bd03e6a9dce45b4104'] = 'Le compte ou la clé de licence est incorrect. Veuillez vérifier le compte et la clé de licence avant de tester la connexion à nouveau.';
$_MODULE['<{avalaratax}prestashop>avalaratax_3b4f001aa4a4715a2449b8affb2eb3f5'] = 'Erreur(s) :';
$_MODULE['<{avalaratax}prestashop>avalaratax_d284d38f7ef7a9d00d82f8395510c845'] = 'Les commandes que vous avez choisies ont été postées.';
$_MODULE['<{avalaratax}prestashop>avalaratax_91b736ea6bbca1d447985ff6262cde25'] = 'L\'erreur suivante a été générée pendant l\'envoi des commandes choisies à Avalara.';
$_MODULE['<{avalaratax}prestashop>avalaratax_62b4a111d5272f0d5e6da820de9fee8d'] = 'Les commandes que vous avez choisies ont été commités.';
$_MODULE['<{avalaratax}prestashop>avalaratax_c45e7677f4f5ccc23c0e4a6989308e8e'] = 'L\'erreur suivante a été générée pendant l\'annulation des commandes choisies d\'Avalara.';
$_MODULE['<{avalaratax}prestashop>avalaratax_2ac3d2e77dddb4c35713ba077a3a9639'] = 'Les commandes que vous avez choisies ont été annulées.';
